import peasy.*;


PeasyCam cam;

/**
 * Crazy Flocking 3D Birds 
 * by Ira Greenberg. 
 * 
 * Simulates a flock of birds using a Bird class and nested
 * pushMatrix() / popMatrix() functions. 
 * Trigonometry functions handle the flapping and sinuous movement.
 * 
 * More realistic flocking behaviour, a camera and a predator added by Joren Six.
 */

// Flock array
int birdCount = 100;
Bird[]birds = new Bird[birdCount];

int predatorCount = 1;
Bird[] predators = new Bird[predatorCount];


void setup() {
  size(screen.width,screen.height,P3D);
  noStroke();
    
  cam = new PeasyCam(this, 1000);
  cam.setMinimumDistance(50);
  cam.setMaximumDistance(50000);

  frameRate(60);
  
  for(int p = 0; p < predatorCount ; p++){
      predators[p] = new Bird(null);
  }
  
  // Initialize arrays with random values
  for (int i = 0; i < birdCount; i++){
    birds[i] = new Bird(predators);
  }
    
  for(int j = 0 ; j < birdCount;j++){  
    for(int p = 0; p < predatorCount ; p++){
      predators[p].addNeighbour(birds[j]);
    }
      
    for(int i=0 ; i<birdCount;i++){
      if(i!=j){
        birds[j].addNeighbour(birds[i]);     
      }
    }    
  }
  
}

void draw() {
  background(0);
  lights();
  for (int i = 0; i < birdCount; i++){
    birds[i].fly();
  }
  
  for(int p = 0; p < predatorCount ; p++){
      predators[p].fly();
    }
  
}


